@@ -1,11 +1,29 @@
+/*
+ * Copyright 2021 l1npengtul <l1npengtul@protonmail.com> / The Nokhwa Contributors
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
 use crate::{backends::capture::OpenCvCaptureDevice, CaptureBackendTrait, NokhwaError};
 use image::{buffer::ConvertBuffer, ImageBuffer, Rgb, RgbaImage};
 use std::cell::RefCell;
 #[cfg(feature = "output-wgpu")]
 use wgpu::{
     Device as WgpuDevice, Extent3d, ImageCopyTexture, ImageDataLayout, Queue as WgpuQueue,
-    Texture as WgpuTexture, TextureDescriptor, TextureDimension, TextureFormat, TextureUsage,
+    Texture as WgpuTexture, TextureAspect, TextureDescriptor, TextureDimension, TextureFormat,
+    TextureUsages,
 };
+
 /// A struct that supports IP Cameras via the `OpenCV` backend.
 pub struct NetworkCamera {
     ip: String,
@@ -106,17 +124,17 @@ impl NetworkCamera {
             sample_count: 1,
             dimension: TextureDimension::D2,
             format: TextureFormat::Rgba8UnormSrgb,
-            usage: TextureUsage::SAMPLED | TextureUsage::COPY_DST,
+            usage: TextureUsages::TEXTURE_BINDING | TextureUsages::COPY_DST,
         });
 
         let width_nonzero = match NonZeroU32::try_from(4 * rgba_frame.width()) {
             Ok(w) => Some(w),
-            Err(why) => return Err(NokhwaError::CouldntCaptureFrame(why.to_string())),
+            Err(why) => return Err(NokhwaError::ReadFrameError(why.to_string())),
         };
 
         let height_nonzero = match NonZeroU32::try_from(rgba_frame.height()) {
             Ok(h) => Some(h),
-            Err(why) => return Err(NokhwaError::CouldntCaptureFrame(why.to_string())),
+            Err(why) => return Err(NokhwaError::ReadFrameError(why.to_string())),
         };
 
         queue.write_texture(
@@ -124,6 +142,7 @@ impl NetworkCamera {
                 texture: &texture,
                 mip_level: 0,
                 origin: wgpu::Origin3d::ZERO,
+                aspect: TextureAspect::All,
             },
             &rgba_frame.to_vec(),
             ImageDataLayout {
